@@ -35,3 +35,12 @@ except:
         def __repr__(self):
             return 'defaultdict(%s, %s)' % (self.default_factory,
                                             dict.__repr__(self))
+
+try:
+    __builtins__.any
+except AttributeError:
+    def any(iter):
+        for item in iter:
+            if item:
+                return True
+        return False
